@@ -99,10 +99,8 @@ class KolibriAuthPermissionsFilter(filters.BaseFilterBackend):
     """
 
     def filter_queryset(self, request, queryset, view):
-        if request.method == "GET" and request.resolver_match.url_name.endswith(
-            "-list"
-        ):
-            # only filter down the queryset in the case of the list view being requested
+        if request.method == "GET":
+            # If a 'GET' method only return readable items to filter down the queryset.
             return request.user.filter_readable(queryset)
         # otherwise, return the full queryset, as permission checks will happen object-by-object
         # (and filtering here then leads to 404's instead of the more correct 403's)
@@ -238,11 +236,6 @@ class FacilityUserFilter(FilterSet):
     def filter_exclude_coach_for(self, queryset, name, value):
         return queryset.exclude(
             Q(roles__in=Role.objects.filter(kind=role_kinds.COACH, collection=value))
-            | Q(
-                roles__in=Role.objects.filter(
-                    kind=role_kinds.COACH, collection_id=value.parent_id
-                )
-            )
         )
 
     def filter_exclude_user_type(self, queryset, name, value):
